@@ -1,24 +1,11 @@
-from typing import TypedDict
-
 import pytest
 
 from pypixiv.client import PixivClient
-
-
-class Filterd(TypedDict):
-    obj: object
-    name: str
-
-
-def filter_magicmethod(obj: object) -> list[Filterd]:
-    return [
-        {"obj": obj, "name": property_name}
-        for property_name in list(filter(lambda d: "_" not in d, dir(obj)))
-    ]
+from tests.util import filter_magicmethod
 
 
 @pytest.mark.asyncio
-async def test_userinfo(client: PixivClient):
+async def test_illustinfo(client: PixivClient):
     user = await client.illustinfo(79136250)
     property_names = filter_magicmethod(user)
 
